@@ -1,18 +1,27 @@
-modelFrame <- structure(function #Multilevel modeling
-###Multilevel modeling of data frames with factor-level columns.
-                        ##details<< Default arguments produce modeling
-                        ##of tree growth from dendrochonological data
+modelFrame <- structure(function #MEDS modeling 
+### This function develops recursive modeling and/or LME detrending of
+### multilevel ecological data series (MEDS).
+                        ##details<< Diverse one-level functions are
+                        ##recursively implemented. Processed MEDS can
+                        ##also be detrended with \code{\link{lme}}
+                        ##models and other \code{\link{nlme}}
+                        ##methods. Default arguments produce modeling
+                        ##of tree growth from dendrochonological MEDS
                         ##with recursive implementation of
                         ##\code{\link{rtimes}}, \code{\link{scacum}},
                         ##\code{\link{amod}}, and
-                        ##\code{\link{ringLme}}. Nevertheless, other
-                        ##functions can also be implemented (see
-                        ##example with climatic data). Internal
-                        ##algorithm uses \code{\link{arguSelect}} and
-                        ##\code{\link{ringApply}}. Consequently,
-                        ##arguments not to be vectorized should be
-                        ##specified in a 'MoreArgs' list (see
-                        ##example).
+                        ##\code{\link{frametoLme}}
+                        ##functions. Nevertheless, other functions can
+                        ##be implemented (see example with climatic
+                        ##data). Internal algorithm uses
+                        ##\code{\link{arguSelect}} and
+                        ##\code{\link{ringApply}}
+                        ##functions. Consequently, arguments not to be
+                        ##vectorized should be specified in 'MoreArgs'
+                        ##lists (see example). Objects of type
+                        ##\code{modelFrame} can further be modified
+                        ##with \code{\link{update}} function.
+
                         ##references<< Lara W., F. Bravo,
                         ##D. Maguire. 2013. Modeling patterns between
                         ##drought and tree biomass growth from
@@ -20,10 +29,11 @@ modelFrame <- structure(function #Multilevel modeling
                         ##approach. Agric. For. Meteorol.,
                         ##178-179:140-151.
 (
-    rd, ##<<\code{data.frame} object with factor-level columns.
-    lv = list(2,1,1), ##<<List of \code{numeric} positions in the
-                      ##factor-level columns to implement one-level
-                      ##functions, or \code{character} names of such
+    rd, ##<<\code{data.frame}. Multilevel ecological data series.
+    lv = list(2,1,1), ##<< List of \code{numeric} positions in the
+                      ##factor-level columns of the processed MEDS to
+                      ##implement the one-level functions, or
+                      ##\code{character} names of the factor-level
                       ##columns.
     fn = list('rtimes','scacum','amod'), ##<< List of \code{character}
                                          ##names of the one-level
@@ -34,10 +44,10 @@ modelFrame <- structure(function #Multilevel modeling
                  ##methods are available: 'lmeForm' or 'tdForm'. These
                  ##methods implement functions with the same names
                  ##(see \code{\link{lmeForm}} and
-                 ##\code{\link{tdForm}}). If \code{NULL} then such a
+                 ##\code{\link{tdForm}}). If \code{NULL} then the lme
                  ##modeling is not developed.
-    ... ##<< Combined arguments to be evaluated by functions in
-        ##\code{fn} (see details).
+    ... ##<< Further arguments to be evaluated by one-level or
+        ##\code{\link{lme}} functions (see details).
 ) {
     
     ar <- list()
@@ -47,17 +57,15 @@ modelFrame <- structure(function #Multilevel modeling
         ar[[i]] <- arguSelect(rd,
                               lv = lv[[i]],fn = fn[[i]],...)
         rd <- do.call(ringApply,ar[[i]])}
-    
     if(!is.null(form)){
         ar <- arguSelect(rd,
-                         fun = c('ringLme',form),...)
+                         fun = c('frametoLme','lme',form),...)
         ar[['form']] <- form
-        rd <- do.call(ringLme,ar)
+        rd <- do.call(frametoLme,ar)
         rd[['call']] <- sys.call()}
-    
     return(rd)
-###Depending on \code{form}, either data frame, or fitted lme object
-###(see \code{\link{nlmeObject}}).
+###Depending on the \code{form} argument, either MEDS or
+###\code{\link{lme}} object.
 } , ex=function() {
     
     ##Multilevel data frame of tree-ring widths:
@@ -68,9 +76,12 @@ modelFrame <- structure(function #Multilevel modeling
     data(PTclim05,envir = environment())
     
     ## Modeling tree growth:
-    ar <- modelFrame(Prings05, y = Pradii03,form = 'tdForm',
+    ar <- modelFrame(Prings05,
+                     y = Pradii03,
+                     form = 'tdForm',
                      MoreArgs = list(only.dup = TRUE,
-                                     mp = c(1,1),un = c('mm','cm'),z = 2003))
+                                     mp = c(1,1),
+                                     un = c('mm','cm'),z = 2003))
     head(ar$resid)
     summary(ar$model)    
     ##a plot of the tree-growth fluctuations:
